﻿/*******************************************************************************
File        : Company.cs
Description : 
--------------------------------------------------------------------------------
Functions:
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
using System;
using System.Windows.Forms;
using Wiker.WIDatabase;
using System.Text;
using System.IO;
using System.Drawing;

namespace WIDatabaseSample
{
/*******************************************************************************
Class        : MainForm
Description  : 
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
public partial class MainForm
{
/*******************************************************************************
Function    : NewCompanySELECT()
Description : 
Parameters  : stCompany company - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
bool NewCompanySELECT(stCompany company)
{
WIDBUtil dbUtil;
string Str;

/* Create Connection To Database */
dbUtil = new WIDBUtil(GetDBInfo());

if (dbUtil.LastError != eDBErrorCodes.None)
   {
   Str = string.Format("Failed to open database\n{0}\nLastError = {1}", GetDBName(dbUtil.DatabaseType),
      dbUtil.LastError.ToString());
   MessageBox.Show(Str);
   return(false);
   }

if (!dbUtil.Open()) /* Open Database */
   {
   Str = string.Format("Failed to open database\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
      dbUtil.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/

/* Save Company Address */
if (!SaveAddressSELECT(dbUtil, company.Address))
   {
   dbUtil.Close();
   Str = string.Format("Failed to Save Address\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
      dbUtil.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Save Company Logo If Exists */
if (company.LogoImage != null)
   {
   if (!SaveImageSELECT(dbUtil, company.LogoImage, out company.LogoID))
      {
      dbUtil.Close();
      Str = string.Format("Failed to Save Logo Image\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
         dbUtil.LastErrorMessage);
      MessageBox.Show(Str);
      return(false);
      }
   }

/* Save Company Infomation */
if (!SaveCompanySELECT(dbUtil, company))
   {
   dbUtil.Close();
   Str = string.Format("Failed to Save Company\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
      dbUtil.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Save Company Work Phone */
if (!SavePhoneSELECT(dbUtil, company.CompanyID, 0, ePhoneType.Work, company.Phone))
   {
   dbUtil.Close();
   Str = string.Format("Failed to Save Work Phone\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
      dbUtil.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Save Company Fax Phone */
if (!SavePhoneSELECT(dbUtil, company.CompanyID, 0, ePhoneType.Fax, company.Fax))
   {
   dbUtil.Close();
   Str = string.Format("Failed to Save Fax Phone\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
      dbUtil.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

dbUtil.Close();

return(true);
}
/*******************************************************************************
Function    : SaveAddressSELECT()
Description : 
Parameters  : DBUtil dbUtil - 
            : stAddress address - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
bool SaveAddressSELECT(WIDBUtil dbUtil, stAddress address)
{
StringBuilder StrB;
string Str;

StrB = new StringBuilder();
StrB.Append("INSERT INTO tblAddress ");
StrB.Append("(Address1, Address2, City, State, ZipCode) ");
StrB.AppendFormat("Values ('{0}', '{1}', '{2}', '{3}', '{4}') ", address.Address1, address.Address2,
   address.City, address.State, address.ZipCode);

try
{
if (!dbUtil.ExecuteTransaction(StrB.ToString(), out address.AddressID))
   return(false);

return(true);
}

catch (Exception ex)
   {
   Str = string.Format("Failed to Create Address\n{0}", ex.Message);
   MessageBox.Show(Str);
   return(false);
   }
}
/*******************************************************************************
Function    : SaveCompanySELECT()
Description : 
Parameters  : DBUtil dbUtil - 
            : stCompany company - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
bool SaveCompanySELECT(WIDBUtil dbUtil, stCompany company)
{
StringBuilder StrB;
int Active;
string Str;

if (company.Active)
   Active = 1;

else
   Active = 0;

StrB = new StringBuilder();
StrB.Append("INSERT INTO tblCompany ");
StrB.Append("(Name, WebSite, Active, AddressID, LogoID) ");
StrB.AppendFormat("Values ('{0}', '{1}', {2}, {3}, {4}) ", company.Name, company.WebSite, Active,
   company.Address.AddressID, company.LogoID);

try
{
if (!dbUtil.ExecuteTransaction(StrB.ToString(), out company.CompanyID))
   return(false);

return(true);
}

catch (Exception ex)
   {
   Str = string.Format("Failed to Create Company\n{0}", ex.Message);
   MessageBox.Show(Str);
   return(false);
   }
}
/*******************************************************************************
Function    : SavePhoneSELECT()
Description : 
Parameters  : WIDBUtil dbUtil - 
            : int companyID - 
            : int personID - 
            : ePhoneType phoneType - 
            : string phoneNumber - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool SavePhoneSELECT(WIDBUtil dbUtil, int companyID, int personID, ePhoneType phoneType, string phoneNumber)
{
string Str;
StringBuilder StrB;

StrB = new StringBuilder();

if (companyID > 0)
   {
   StrB.Append("INSERT INTO tblPhone ");
   StrB.Append("(CompanyID, Type, Number) ");
   StrB.AppendFormat("Values ({0}, {1}, '{2}') ", companyID, (int)phoneType, phoneNumber);
   }

else
if (personID > 0)
   {
   StrB.Append("INSERT INTO tblPhone ");
   StrB.Append("(PersonID, Type, Number) ");
   StrB.AppendFormat("Values ({0}, {1}, '{2}') ", personID, (int)phoneType, phoneNumber);
   }

else
   return(false);

try
{
if (!dbUtil.ExecuteTransaction(StrB.ToString()))
   return(false);

return(true);
}

catch (Exception ex)
   {
   Str = string.Format("Failed to Create Phone\n{0}", ex.Message);
   MessageBox.Show(Str);
   return(false);
   }
}
/*******************************************************************************
Function    : SaveImageSELECT()
Description : 
Parameters  : WIDBUtil dbUtil - 
            : Image image - 
            : out int id - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool SaveImageSELECT(WIDBUtil dbUtil, Image image, out int id)
{
string Str;
StringBuilder StrB;

id = 0;

StrB = new StringBuilder();
StrB.Append("INSERT INTO tblImage ");
StrB.Append("(ImageData) ");
StrB.Append("VALUES (@ImageData)");

dbUtil.AddParameter("@ImageData", image);

try
{
if (!dbUtil.ExecuteTransaction(StrB.ToString(), out id))
   return(false);

return(true);
}

catch (Exception ex)
   {
   Str = string.Format("Failed to Create Phone\n{0}", ex.Message);
   MessageBox.Show(Str);
   return(false);
   }
}
/*******************************************************************************
Function    : UpdateCompanySELECT()
Description : 
Parameters  : stCompany company - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/04/12 WLM Created
*******************************************************************************/
bool UpdateCompanySELECT(stCompany company)
{
WIDBUtil dbUtil;
string Str;

/* Create Connection To Database */
dbUtil = new WIDBUtil(GetDBInfo());

if (dbUtil.LastError != eDBErrorCodes.None)
   {
   Str = string.Format("Failed to open database\n{0}\nLastError = {1}", GetDBName(dbUtil.DatabaseType),
      dbUtil.LastError.ToString());
   MessageBox.Show(Str);
   return(false);
   }

if (!dbUtil.Open()) /* Open Database */
   {
   Str = string.Format("Failed to open database\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
      dbUtil.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/

/* Update Company Address */
if (!UpdateAddressSELECT(dbUtil, company.Address))
   {
   dbUtil.Close();
   Str = string.Format("Failed to Update Address\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
      dbUtil.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/

/* Update Company Logo If Exists */
if (company.LogoImage != null)
   {
   if (company.LogoID > 0) /* Update Existing Image */
      {
      if (!UpdateImageSELECT(dbUtil, company.LogoImage, company.LogoID))
         {
         dbUtil.Close();
         Str = string.Format("Failed to Update Logo Image\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
            dbUtil.LastErrorMessage);
         MessageBox.Show(Str);
         return(false);
         }
      }

   else
      {  /* New Image */
      if (!SaveImageSELECT(dbUtil, company.LogoImage, out company.LogoID))
         {
         dbUtil.Close();
         Str = string.Format("Failed to Save Logo Image\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
            dbUtil.LastErrorMessage);
         MessageBox.Show(Str);
         return(false);
         }
      }
   }

else
if(company.LogoID > 0) /* Delete Existing Image */
   {
   if (!DeleteImageSELECT(dbUtil, company.LogoID))
      {
      dbUtil.Close();
      Str = string.Format("Failed to Delete Logo Image\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
         dbUtil.LastErrorMessage);
      MessageBox.Show(Str);
      return(false);
      }
   }

/*----------------------------------------------------------------------------*/

/* Update Company Infomation */
if (!UpdateCompanySELECT(dbUtil, company))
   {
   dbUtil.Close();
   Str = string.Format("Failed to Update Company\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
      dbUtil.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Update Company Work Phone */
if (!UpdatePhoneSELECT(dbUtil, company.CompanyID, 0, ePhoneType.Work, company.Phone))
   {
   dbUtil.Close();
   Str = string.Format("Failed to Update Work Phone\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
      dbUtil.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/* Update Company Fax Phone */
if (!UpdatePhoneSELECT(dbUtil, company.CompanyID, 0, ePhoneType.Fax, company.Fax))
   {
   dbUtil.Close();
   Str = string.Format("Failed to Update Fax Phone\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
      dbUtil.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

dbUtil.Close();

return(true);
}
/*******************************************************************************
Function    : UpdateAddressSELECT()
Description : 
Parameters  : WIDBUtil dbUtil - 
            : stAddress address - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/11 WLM Created
*******************************************************************************/
bool UpdateAddressSELECT(WIDBUtil dbUtil, stAddress address)
{
StringBuilder StrB;
string Str;
bool Result;

if (address == null || address.AddressID < 1)
   return(false);

StrB = new StringBuilder();
StrB.Append("UPDATE tblAddress SET ");
StrB.AppendFormat("Address1 = '{0}', ", address.Address1);
StrB.AppendFormat("Address2 = '{0}', ", address.Address2);
StrB.AppendFormat("City = '{0}', ", address.City);
StrB.AppendFormat("State = '{0}', ", address.State);
StrB.AppendFormat("ZipCode = '{0}' ", address.ZipCode);
StrB.AppendFormat("WHERE AddressID = {0} ", address.AddressID);

try
{
Result = dbUtil.ExecuteTransaction(StrB.ToString());

return(Result);
}

catch (Exception ex)
   {
   Str = string.Format("Failed to Update Address\n{0}", ex.Message);
   MessageBox.Show(Str);
   return(false);
   }
}
/*******************************************************************************
Function    : UpdateCompanySELECT()
Description : 
Parameters  : WIDBUtil dbUtil - 
            : stCompany company - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/11 WLM Created
*******************************************************************************/
bool UpdateCompanySELECT(WIDBUtil dbUtil, stCompany company)
{
StringBuilder StrB;
int Active;
string Str;
bool Result;

if (company == null || company.CompanyID < 1)
   return(false);

if (company.Active)
   Active = 1;

else
   Active = 0;

StrB = new StringBuilder();
StrB.Append("UPDATE tblCompany SET ");
StrB.AppendFormat("Name = '{0}', ", company.Name);
StrB.AppendFormat("WebSite = '{0}', ", company.WebSite);
StrB.AppendFormat("Active = '{0}', ", Active);
StrB.AppendFormat("AddressID = '{0}', ", company.Address.AddressID);
StrB.AppendFormat("LogoID = '{0}' ", company.LogoID);
StrB.AppendFormat("WHERE CompanyID = {0} ", company.CompanyID);

try
{
Result = dbUtil.ExecuteTransaction(StrB.ToString());

return(Result);
}

catch (Exception ex)
   {
   Str = string.Format("Failed to Update Company\n{0}", ex.Message);
   MessageBox.Show(Str);
   return(false);
   }
}
/*******************************************************************************
Function    : UpdatePhoneSELECT()
Description : 
Parameters  : WIDBUtil dbUtil - 
            : int companyID - 
            : int personID - 
            : ePhoneType phoneType - 
            : string phoneNumber - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool UpdatePhoneSELECT(WIDBUtil dbUtil, int companyID, int personID, ePhoneType phoneType, string phoneNumber)
{
string Str;
StringBuilder StrB;
bool Result;

StrB = new StringBuilder();
StrB.Append("UPDATE tblPhone SET ");
StrB.AppendFormat("Number = '{0}' ", phoneNumber);

if (companyID > 0)
   StrB.AppendFormat("WHERE CompanyID = {0} AND Type = {1} ", companyID, (int)phoneType);

else
if (personID > 0)
   StrB.AppendFormat("WHERE PersonID = {0} AND Type = {1} ", personID, (int)phoneType);

else
   return(false);

/*----------------------------------------------------------------------------*/

try
{
Result = dbUtil.ExecuteTransaction(StrB.ToString());

return(Result);
}

catch (Exception ex)
   {
   Str = string.Format("Failed to Update Phone\n{0}", ex.Message);
   MessageBox.Show(Str);
   return(false);
   }
}
/*******************************************************************************
Function    : UpdateImageSELECT()
Description : 
Parameters  : WIDBUtil dbUtil - 
            : Image image - 
            : int imageID - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool UpdateImageSELECT(WIDBUtil dbUtil, Image image, int imageID)
{
string Str;
StringBuilder StrB;
bool Result;

if (imageID < 1)
   return(false);

StrB = new StringBuilder();
StrB.Append("UPDATE tblImage SET ");
StrB.Append("ImageData = @ImageData ");
StrB.AppendFormat("WHERE ImageID = {0} ", imageID);

dbUtil.AddParameter("@ImageData", image);

try
{
Result = dbUtil.ExecuteTransaction(StrB.ToString());

return(Result);
}

catch (Exception ex)
   {
   Str = string.Format("Failed to Update Phone\n{0}", ex.Message);
   MessageBox.Show(Str);
   return(false);
   }
}
/*******************************************************************************
Function    : LoadCompanyNamesSELECT()
Description : 
Parameters  : None
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/04/14 WLM Created
*******************************************************************************/
bool LoadCompanyNamesSELECT()
{
WIDBUtil dbUtil;
string Str;
StringBuilder StrB;
stCompany Company;
stComboItem ComboItem;

dbUtil = null;

try
{
/* Create Connection To Database */
dbUtil = new WIDBUtil(GetDBInfo());

if (dbUtil.LastError != eDBErrorCodes.None)
   {
   Str = string.Format("Failed to open database\n{0}\nLastError = {1}", GetDBName(dbUtil.DatabaseType),
      dbUtil.LastError.ToString());
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/

StrB = new StringBuilder(); /* Build Select Request */
StrB.Append("SELECT CompanyID, Name ");
StrB.Append("FROM tblCompany ");
StrB.Append("ORDER BY Name ASC");

if (!dbUtil.Open()) /* Open Database */
   {
   Str = string.Format("Failed to open database\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
      dbUtil.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

dbUtil.CommandText = StrB.ToString();

while (dbUtil.ReadRow()) /* Loop Through Results */
   {
   Company = new stCompany();
   Company.CompanyID = dbUtil.ReadInt(0);
   Company.Name = dbUtil.ReadString(1);

   /* Add Company Names To ComboBoxes */
   ComboItem = new stComboItem(Company.Name, Company);
   comboCompanyCompany.Items.Add(ComboItem);
   comboPersonCompany.Items.Add(ComboItem);
   }

dbUtil.Close();

return(true);
}

catch (Exception ex)
   {
   if (dbUtil != null)
      dbUtil.Close();

   Str = string.Format("LoadCompanyNamesSELECT() Exception\n{0}", ex.Message);
   MessageBox.Show(Str);
   return(false);
   }
}
/*******************************************************************************
Function    : SearchCompanySELECT()
Description : 
Parameters  : stCompany company - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/11 WLM Created
*******************************************************************************/
bool SearchCompanySELECT(stCompany company)
{
WIDBUtil dbUtil;
StringBuilder StrB;
string Str;

dbUtil = null;

try
{
/* Create Connection To Database */
dbUtil = new WIDBUtil(GetDBInfo());

if (dbUtil.LastError != eDBErrorCodes.None)
   {
   Str = string.Format("Failed to open database\n{0}\nLastError = {1}", GetDBName(dbUtil.DatabaseType),
      dbUtil.LastError.ToString());
   MessageBox.Show(Str);
   return(false);
   }

StrB = new StringBuilder(); /* Build Select Request */
StrB.Append("SELECT tblCompany.CompanyID, tblCompany.AddressID, Name, LogoID, ");
StrB.Append("WebSite, Active, Address1, Address2, City, State, ZipCode, ImageData, ");
StrB.Append("P1.Number AS CompanyPhone, P2.Number AS CompanyFax ");
StrB.Append("FROM tblCompany ");
StrB.Append("LEFT JOIN tblAddress ON (tblAddress.AddressID = tblCompany.AddressID) ");
StrB.Append("LEFT JOIN tblImage ON (tblImage.ImageID = LogoID) ");
StrB.AppendFormat("LEFT JOIN tblPhone P1 ON (P1.CompanyID = tblCompany.CompanyID AND P1.Type = {0}) ",
   (int)ePhoneType.Work);
StrB.AppendFormat("LEFT JOIN tblPhone P2 ON (P2.CompanyID = tblCompany.CompanyID AND P2.Type = {0}) ",
   (int)ePhoneType.Fax);
StrB.AppendFormat("WHERE tblCompany.CompanyId = {0} ", company.CompanyID);

dbUtil.CommandText = StrB.ToString();

if (!dbUtil.Open()) /* Open Database */
   {
   Str = string.Format("Failed to open database\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
      dbUtil.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

if (!dbUtil.ReadRow())
   {
   Str = string.Format("Failed to ReadRow\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
      dbUtil.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/

/*
0 CompanyID
1 AddressID
2 Name
3 LogoID
4 WebSite
5 Active
6 Address1
7 Address2
8 City
9 State
10 ZipCode

11 ImageData
12 CompanyPhone
13 CompanyFax
*/

company.CompanyID = dbUtil.ReadInt(0);
company.Address.AddressID = dbUtil.ReadInt(1);
company.Name = dbUtil.ReadString(2);
company.LogoID = dbUtil.ReadInt(3);
company.WebSite = dbUtil.ReadString(4);
company.Active = dbUtil.ReadBool(5);
company.Address.Address1 = dbUtil.ReadString(6);
company.Address.Address2 = dbUtil.ReadString(7);
company.Address.City = dbUtil.ReadString(8);
company.Address.State = dbUtil.ReadString(9);
company.Address.ZipCode = dbUtil.ReadString(10);

company.LogoImage = dbUtil.ReadImage(11);

company.Phone = dbUtil.ReadString(12);
company.Fax = dbUtil.ReadString(13);

dbUtil.Close();

return(true);
}

catch (Exception ex)
   {
   if (dbUtil != null)
      dbUtil.Close();

   Str = string.Format("SearchCompanySELECT() Exception\n{0}", ex.Message);
   MessageBox.Show(Str);
   return(false);
   }
}
/*******************************************************************************
Function    : DeleteCompanySELECT()
Description : 
Parameters  : stCompany company - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/12 WLM Created
*******************************************************************************/
bool DeleteCompanySELECT(stCompany company)
{
WIDBUtil dbUtil;
string Str;

/* Create Connection To Database */
dbUtil = new WIDBUtil(GetDBInfo());

if (dbUtil.LastError != eDBErrorCodes.None)
   {
   Str = string.Format("Failed to open database\n{0}\nLastError = {1}", GetDBName(dbUtil.DatabaseType),
      dbUtil.LastError.ToString());
   MessageBox.Show(Str);
   return(false);
   }

if (!dbUtil.Open()) /* Open Database */
   {
   Str = string.Format("Failed to open database\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
      dbUtil.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

/*----------------------------------------------------------------------------*/

if (company.Address.AddressID > 0)
   {
   if (!DeleteAddressSELECT(dbUtil, company.Address))
      {
      dbUtil.Close();
      Str = string.Format("Failed to Delete Address\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
         dbUtil.LastErrorMessage);
      MessageBox.Show(Str);
      return(false);
      }
   }

if (company.LogoID > 0)
   {
   if (!DeleteImageSELECT(dbUtil, company.LogoID))
      {
      dbUtil.Close();
      Str = string.Format("Failed to Delete Logo\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
         dbUtil.LastErrorMessage);
      MessageBox.Show(Str);
      return(false);
      }
   }

if (!DeletePhoneSELECT(dbUtil, company.CompanyID, 0, ePhoneType.Work))
   {
   dbUtil.Close();
   Str = string.Format("Failed to Delete Work Phone\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
      dbUtil.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

if (!DeletePhoneSELECT(dbUtil, company.CompanyID, 0, ePhoneType.Fax))
   {
   dbUtil.Close();
   Str = string.Format("Failed to Delete Fax\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
      dbUtil.LastErrorMessage);
   MessageBox.Show(Str);
   return(false);
   }

if (company.CompanyID > 0)
   {
   if (!DeleteCompanySELECT(dbUtil, company.CompanyID))
      {
      dbUtil.Close();
      Str = string.Format("Failed to Delete Company\nLastError = {0}\n{1}", dbUtil.LastError.ToString(),
         dbUtil.LastErrorMessage);
      MessageBox.Show(Str);
      return(false);
      }
   }

dbUtil.Close();

return(true);
}
/*******************************************************************************
Function    : DeleteAddressSELECT()
Description : 
Parameters  : WIDBUtil dbUtil - 
            : stAddress address - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/12 WLM Created
*******************************************************************************/
bool DeleteAddressSELECT(WIDBUtil dbUtil, stAddress address)
{
StringBuilder StrB;
string Str;
bool Result;

if (address == null || address.AddressID < 1)
   return(false);

StrB = new StringBuilder();
StrB.Append("DELETE FROM tblAddress ");
StrB.AppendFormat("WHERE AddressID = {0} ", address.AddressID);

try
{
Result = dbUtil.ExecuteTransaction(StrB.ToString());

return(Result);
}

catch (Exception ex)
   {
   Str = string.Format("Failed to Delete Address\n{0}", ex.Message);
   MessageBox.Show(Str);
   return(false);
   }
}
/*******************************************************************************
Function    : DeleteCompanySELECT()
Description : 
Parameters  : WIDBUtil dbUtil - 
            : int companyID - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool DeleteCompanySELECT(WIDBUtil dbUtil, int companyID)
{
StringBuilder StrB;
string Str;
bool Result;

if (companyID < 1)
   return(false);


StrB = new StringBuilder();
StrB.Append("DELETE FROM tblCompany ");
StrB.AppendFormat("WHERE CompanyID = {0} ", companyID);

try
{
Result = dbUtil.ExecuteTransaction(StrB.ToString());

return(Result);
}

catch (Exception ex)
   {
   Str = string.Format("Failed to Delete Company\n{0}", ex.Message);
   MessageBox.Show(Str);
   return(false);
   }
}
/*******************************************************************************
Function    : DeletePhoneSELECT()
Description : 
Parameters  : WIDBUtil dbUtil - 
            : int companyID - 
            : int personID - 
            : ePhoneType phoneType - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/16 WLM Created
*******************************************************************************/
bool DeletePhoneSELECT(WIDBUtil dbUtil, int companyID, int personID, ePhoneType phoneType)
{
string Str;
StringBuilder StrB;
bool Result;

if (companyID < 1 && personID < 1)
   return(false);

StrB = new StringBuilder();
StrB.Append("DELETE FROM tblPhone ");

if (companyID > 1)
   StrB.AppendFormat("WHERE CompanyID = {0} AND Type = {1} ", companyID, (int)phoneType);

else
if (personID > 1)
   StrB.AppendFormat("WHERE PersonID = {0} AND Type = {1} ", personID, (int)phoneType);

else
   return(false);

try
{
Result = dbUtil.ExecuteTransaction(StrB.ToString());

return(Result);
}

catch (Exception ex)
   {
   Str = string.Format("Failed to Delete Phone\n{0}", ex.Message);
   MessageBox.Show(Str);
   return(false);
   }
}
/*******************************************************************************
Function    : DeleteImageSELECT()
Description : 
Parameters  : WIDBUtil dbUtil - 
            : int imageID - 
Returns     : bool
--------------------------------------------------------------------------------
History:
2011/05/13 WLM Created
*******************************************************************************/
bool DeleteImageSELECT(WIDBUtil dbUtil, int imageID)
{
string Str;
StringBuilder StrB;
bool Result;

if (imageID < 1)
   return(false);

StrB = new StringBuilder();
StrB.Append("DELETE FROM tblImage ");
StrB.AppendFormat("WHERE ImageID = {0} ", imageID);

try
{
Result = dbUtil.ExecuteTransaction(StrB.ToString());

return(Result);
}

catch (Exception ex)
   {
   Str = string.Format("Failed to Delete Phone\n{0}", ex.Message);
   MessageBox.Show(Str);
   return(false);
   }
}
} /* End Of Class MainForm */
} /* End Of NameSpace WIDatabaseSample */